﻿<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:msa="http://www.publictalksoftware.co.uk/msa">

	<xsl:variable name="DutyDB" select="document('DutyAssignHistory.xml')"/>
	<xsl:variable name="PubDB" select="document('MSA_PublisherDatabase.xml')"/>

	<xsl:output method="html" encoding="UTF-8" indent="yes"/>

	<xsl:template match="/">
		<html>
			<head>
				<title>Duty History Report</title>
				<link rel="stylesheet" type="text/css" href="Custom--S-140--DutyHistory.css"/>
				<script type="text/javascript">
					function showAlert() {
						var select = document.getElementById('publisherCombo');
						var selectedText = select.options[select.selectedIndex].text;
						// alert("Selected Publisher: " + selectedText);
					}

					function saveDate() {
						var selectedDate = document.getElementById('datePicker').value;
						// alert("Selected Date: " + selectedDate);
						// Save the date to a variable for further use
						window.selectedDate = selectedDate;
					}

					async function filterHistory() {
						try {
							var selectedName = document.getElementById('publisherCombo').value;
							var selectedDate = document.getElementById('datePicker').value.replace(/-/g, '');

							// Check if the date is not selected
							if (!selectedDate) {
								alert('Please select a date.');
								return;
							}

							// Fetch the XML and XSL files asynchronously
							var [xsl, xml, labelsInfo] = await Promise.all([
								loadXMLDoc('DutyHistory-transform.xsl'),
								loadXMLDoc('DutyAssignHistory.xml'),
								loadXMLDoc('LabelsInfo.XML')
							]);

							var xsltProcessor = new XSLTProcessor();
							xsltProcessor.importStylesheet(xsl);

							try {
								xsltProcessor.setParameter(null, 'selectedName', selectedName);
								xsltProcessor.setParameter(null, 'selectedDate', selectedDate);
								xsltProcessor.setParameter(null, 'index1', labelsInfo.documentElement.querySelectorAll("Sound[Index='1']")[0].textContent);
								xsltProcessor.setParameter(null, 'index2', labelsInfo.documentElement.querySelectorAll("Sound[Index='2']")[0].textContent);
								xsltProcessor.setParameter(null, 'index3', labelsInfo.documentElement.querySelectorAll("Sound[Index='3']")[0].textContent);
								xsltProcessor.setParameter(null, 'index4', labelsInfo.documentElement.querySelectorAll("Sound[Index='4']")[0].textContent);
								xsltProcessor.setParameter(null, 'index5', labelsInfo.documentElement.getElementsByTagName('Platform')[0].textContent.trim());
								xsltProcessor.setParameter(null, 'index6', labelsInfo.documentElement.getElementsByTagName('Microphone')[0].textContent.trim());
								xsltProcessor.setParameter(null, 'index7', labelsInfo.documentElement.querySelectorAll("Mike[Index='1']")[0].textContent);
								xsltProcessor.setParameter(null, 'index8', labelsInfo.documentElement.querySelectorAll("Mike[Index='2']")[0].textContent);
								xsltProcessor.setParameter(null, 'index9', labelsInfo.documentElement.querySelectorAll("Mike[Index='3']")[0].textContent);
								xsltProcessor.setParameter(null, 'index10', labelsInfo.documentElement.querySelectorAll("Mike[Index='4']")[0].textContent);
								xsltProcessor.setParameter(null, 'index11', labelsInfo.documentElement.querySelectorAll("Mike[Index='5']")[0].textContent);
								xsltProcessor.setParameter(null, 'index12', labelsInfo.documentElement.querySelectorAll("Mike[Index='6']")[0].textContent);
								xsltProcessor.setParameter(null, 'index13', labelsInfo.documentElement.querySelectorAll("Attendant[Index='1']")[0].textContent);
								xsltProcessor.setParameter(null, 'index14', labelsInfo.documentElement.querySelectorAll("Attendant[Index='2']")[0].textContent);
								xsltProcessor.setParameter(null, 'index15', labelsInfo.documentElement.querySelectorAll("Attendant[Index='3']")[0].textContent);
								xsltProcessor.setParameter(null, 'index16', labelsInfo.documentElement.querySelectorAll("Attendant[Index='4']")[0].textContent);
								xsltProcessor.setParameter(null, 'index17', labelsInfo.documentElement.querySelectorAll("Cleaning[Index='1']")[0].textContent);
								xsltProcessor.setParameter(null, 'index18', labelsInfo.documentElement.querySelectorAll("Cleaning[Index='2']")[0].textContent);
								xsltProcessor.setParameter(null, 'indexCustomFixed0', labelsInfo.documentElement.querySelectorAll("ConductorCBS[CustomFixedIndex='0']")[0].textContent);
								xsltProcessor.setParameter(null, 'indexCustomFixed1', labelsInfo.documentElement.querySelectorAll("ReaderCBS[CustomFixedIndex='1']")[0].textContent);
								xsltProcessor.setParameter(null, 'indexCustomFixed2', labelsInfo.documentElement.querySelectorAll("MidweekChairman[CustomFixedIndex='2']")[0].textContent);
								xsltProcessor.setParameter(null, 'indexCustomFixed3', labelsInfo.documentElement.querySelectorAll("MidweekPrayer[CustomFixedIndex='3']")[0].textContent);
								xsltProcessor.setParameter(null, 'indexCustomFixed4', labelsInfo.documentElement.querySelectorAll("Host[CustomFixedIndex='4']")[0].textContent);
								xsltProcessor.setParameter(null, 'indexCustomFixed5', labelsInfo.documentElement.querySelectorAll("CoHost[CustomFixedIndex='5']")[0].textContent);
								xsltProcessor.setParameter(null, 'indexCustomFixed6', labelsInfo.documentElement.querySelectorAll("ZoomAttendant[CustomFixedIndex='6']")[0].textContent);

							} catch (paramError) {
								console.error('Error setting XSLT parameters:', paramError);
								return;
							}

							var resultDocument = xsltProcessor.transformToFragment(xml, document);
							document.getElementById('output').innerHTML = '';
							document.getElementById('output').appendChild(resultDocument);
						} catch (transformError) {
							console.error('Error during XSLT transformation:', transformError);
						}
					}

					function loadXMLDoc(filename) {
						return fetch(filename)
							.then(response => {
								if (!response.ok) {
								throw new Error('Network response was not ok');
								}
								return response.text();
							})
							.then(str => (new window.DOMParser()).parseFromString(str, "text/xml"))
							.catch(error => {
								console.error('There has been a problem with your fetch operation:', error);
							});
					}
				</script>
			</head>
			<body>
				<table class="settings-table no-print">
					<tr>
						<th>
							Publisher:
						</th>
						<th>
							Start Date:
						</th>
					</tr>
					<tr>
						<td>
							<select id="publisherCombo" onchange="showAlert()">
								<xsl:for-each select="$PubDB/msa:PublisherDatabase/msa:Publishers/msa:Publisher[@Gender='Male']">
									<xsl:sort select="msa:Name" order="ascending" data-type="text"/>
									<option>
										<xsl:value-of select="msa:Name"/>
									</option>
								</xsl:for-each>
							</select>
						</td>
						<td>
							<input type="date" id="datePicker" onchange="saveDate()"/>
							<button onclick="filterHistory()">Filter</button>
						</td>
					</tr>
				</table>

				<div id="output"></div>
			</body>
		</html>
	</xsl:template>

</xsl:stylesheet>
